@@ -91,7 +91,7 @@ class Mandrill(object):
         params = json.dumps(params)
         self.log('POST to %s%s.json: %s' % (ROOT, url, params))
         start = time.time()
-        r = self.session.post('%s%s.json' % (ROOT, url), data=params, headers={'content-type': 'application/json', 'user-agent': 'Mandrill-Python/1.0.19'})
+        r = self.session.post('%s%s.json' % (ROOT, url), data=params, headers={'content-type': 'application/json', 'user-agent': 'Mandrill-Python/1.0.22'})
         try:
             remote_addr = r.raw._original_response.fp._sock.getpeername() # grab the remote_addr before grabbing the text since the socket will go away
         except:
@@ -606,6 +606,9 @@ class Inbound(object):
     def send_raw(self, raw_message, to=None):
         """Take a raw MIME document destined for a domain with inbound domains set up, and send it to the inbound hook exactly as if it had been sent over SMTP
 $sparam string $to[] the email address of the recipient @validate trim
+$sparam string $mail_from the address specified in the MAIL FROM stage of the SMTP conversation @validate email. Optional; required for the SPF check.
+$sparam string $helo the identification provided by the client mta in the MTA state of the SMTP conversation. Optional; required for the SPF check.
+$sparam string $client_address the remote MTA's ip address. Optional; required for the SPF check.
 
         Args:
            raw_message (string): the full MIME document of an email message
@@ -852,10 +855,13 @@ class Messages(object):
                message.track_opens (boolean): whether or not to turn on open tracking for the message
                message.track_clicks (boolean): whether or not to turn on click tracking for the message
                message.auto_text (boolean): whether or not to automatically generate a text part for messages that are not given text
+               message.auto_html (boolean): whether or not to automatically generate an HTML part for messages that are not given HTML
                message.inline_css (boolean): whether or not to automatically inline all CSS styles provided in the message HTML - only for HTML documents less than 256KB in size
                message.url_strip_qs (boolean): whether or not to strip the query string from URLs when aggregating tracked URL data
                message.preserve_recipients (boolean): whether or not to expose all recipients in to "To" header for each email
                message.bcc_address (string): an optional address to receive an exact copy of each recipient's email
+               message.tracking_domain (string): a custom domain to use for tracking opens and clicks instead of mandrillapp.com
+               message.signing_domain (string): a custom domain to use for SPF/DKIM signing instead of mandrill (for "via" or "on behalf of" in email clients)
                message.merge (boolean): whether to evaluate merge tags in the message. Will automatically be set to true if either merge_vars or global_merge_vars are provided.
                message.global_merge_vars (array): global merge variables to use for all recipients. You can override these per recipient.::
                    message.global_merge_vars[] (struct): a single global merge variable::
@@ -942,10 +948,13 @@ class Messages(object):
                message.track_opens (boolean): whether or not to turn on open tracking for the message
                message.track_clicks (boolean): whether or not to turn on click tracking for the message
                message.auto_text (boolean): whether or not to automatically generate a text part for messages that are not given text
+               message.auto_html (boolean): whether or not to automatically generate an HTML part for messages that are not given HTML
                message.inline_css (boolean): whether or not to automatically inline all CSS styles provided in the message HTML - only for HTML documents less than 256KB in size
                message.url_strip_qs (boolean): whether or not to strip the query string from URLs when aggregating tracked URL data
                message.preserve_recipients (boolean): whether or not to expose all recipients in to "To" header for each email
                message.bcc_address (string): an optional address to receive an exact copy of each recipient's email
+               message.tracking_domain (string): a custom domain to use for tracking opens and clicks instead of mandrillapp.com
+               message.signing_domain (string): a custom domain to use for SPF/DKIM signing instead of mandrill (for "via" or "on behalf of" in email clients)
                message.global_merge_vars (array): global merge variables to use for all recipients. You can override these per recipient.::
                    message.global_merge_vars[] (struct): a single global merge variable::
                        message.global_merge_vars[].name (string): the global merge variable's name. Merge variable names are case-insensitive and may not start with _
